## English Stopwords

From  https://gist.github.com/sebleier/554280

## Chinese Stopwords


- 综合多个词表（结巴、哈工大、川大），不包含百度停用词，百度停用词中的词是搜索相关的，有些实词和有意义的词也会在里面，所以准确的角度考虑百度停用词最好不使用。
- 人工进行了部分修改（见下表）。

```json
# 删除
风雨无阻
奋勇

# 增加
即是
来到
见到
异于
何谓
没什么
赶到
没啥
123
只剩
途中
只能
所谓
看到
只好
丢下
撇下
看不到
记得
任何理由
最大
```



